@@ -21,23 +21,17 @@ class FieldMapping(NamedTuple):
     field_name: str
     """
     Field name on the :class:`Device` named tuple.
-
-    :type: str
     """
 
     field_type: Callable[[str], Any]
     """
     Field type; a callable to use to parse the string value.
-
-    :type: Callable[[str], Any]
     """
 
     many: bool = False
     """
     Whether or not to use a List, if this field can be repeated multiple times
     in the lspci output.
-
-    :type: bool
     """
 
 
@@ -75,7 +69,7 @@ class VerboseParser(Parser):
         ),
         'NUMANode': FieldMapping(field_name='numa_node', field_type=int),
         'IOMMUGroup': FieldMapping(field_name='iommu_group', field_type=int),
-        'PhySlot': FieldMapping(field_name='physical_slot', field_type=int),
+        'PhySlot': FieldMapping(field_name='physical_slot', field_type=str),
     }
 
     def _parse_device(self, device_data: Union[str, Iterable[str]]) -> Device:
